Module run

Module run 

The run module handles retrieving Runs. A Run maps directly to an uploaded splits file.

API Documentation

Structs

RunWriter
Handles writing a run to the body of an upload request.
UploadedRun
A run that was uploaded to splits.io.

Functions

download
Downloads the splits for a Run.
get
Gets a Run.
upload
Uploads a run to splits.io.