The run module handles retrieving Runs. A Run maps directly to an uploaded splits file.
Structs
- RunWriter
- Handles writing a run to the body of an upload request.
- Uploaded
Run - A run that was uploaded to splits.io.
The run module handles retrieving Runs. A Run maps directly to an uploaded splits file.